@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Perl::Critic::Policy::Lax::ProhibitComplexMappings::LinesNotStatements;
+package Perl::Critic::Policy::Lax::ProhibitComplexMappings::LinesNotStatements 0.014;
 # ABSTRACT: prohibit multiline maps, not multistatement maps
-$Perl::Critic::Policy::Lax::ProhibitComplexMappings::LinesNotStatements::VERSION = '0.013';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod Yes, yes, don't go nuts with map and use it to implement the complex multi-pass
@@ -83,7 +83,7 @@ Perl::Critic::Policy::Lax::ProhibitComplexMappings::LinesNotStatements - prohibi
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 DESCRIPTION
 
@@ -107,13 +107,23 @@ Beyond the fact that it's really ugly, it's just a short step from there to a
 few included loop structures and then -- oops! -- a return statement.
 Seriously, people, they're called subroutines.  We've had them since Perl 3.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo Signes <rjbs@cpan.org>.
+This software is copyright (c) 2022 by Ricardo Signes <cpan@semiotic.systems>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
