@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Perl::Critic::Policy::Lax::ProhibitEmptyQuotes::ExceptAsFallback;
+package Perl::Critic::Policy::Lax::ProhibitEmptyQuotes::ExceptAsFallback 0.014;
 # ABSTRACT: empty quotes are okay as the fallback on the rhs of ||
-$Perl::Critic::Policy::Lax::ProhibitEmptyQuotes::ExceptAsFallback::VERSION = '0.013';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod Sure, C<""> can be confusing when crammed into the middle of a big list of
@@ -62,7 +62,7 @@ Perl::Critic::Policy::Lax::ProhibitEmptyQuotes::ExceptAsFallback - empty quotes
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 DESCRIPTION
 
@@ -80,13 +80,23 @@ It's got a certain charm about it that just isn't manifested by these:
 This policy prohibits all-whitespace strings constructed by single or double
 quotes, except for the empty string when it follows the high-precedence "or" or "defined or" operators.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo Signes <rjbs@cpan.org>.
+This software is copyright (c) 2022 by Ricardo Signes <cpan@semiotic.systems>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
