@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire;
+package Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire 0.014;
 # ABSTRACT: stringy eval is bad, but it's okay just to "require"
-$Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire::VERSION = '0.013';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod Sure, everybody sane agrees that stringy C<eval> is usually a bad thing, but
@@ -107,7 +107,7 @@ Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire - stringy eval
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 DESCRIPTION
 
@@ -130,13 +130,23 @@ something like this:
 
 Then again, maybe you should use L<Module::Runtime>.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo Signes <rjbs@cpan.org>.
+This software is copyright (c) 2022 by Ricardo Signes <cpan@semiotic.systems>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
